# Changelog

## [Unreleased](https://github.com/H2020-OpenModel/WP3-WrapperSDK/tree/HEAD)

[Full Changelog](https://github.com/H2020-OpenModel/WP3-WrapperSDK/compare/v0.1.0...HEAD)

**Closed issues:**

- More tests for new declarative pipeline WorkChain [\#57](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/57)
- AiiDA nodes for strategy types [\#18](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/18)

## [v0.1.0](https://github.com/H2020-OpenModel/WP3-WrapperSDK/tree/v0.1.0) (2022-12-09)

[Full Changelog](https://github.com/H2020-OpenModel/WP3-WrapperSDK/compare/9357d7a1fe585f1b2d13c5e05352ca3a6353383c...v0.1.0)

**Implemented enhancements:**

- Add pre-commit and other developer tools [\#21](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/21)
- 14 publish sdk to pypi [\#19](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/19) ([quaat](https://github.com/quaat))

**Fixed bugs:**

- Fix concurrency for cd\_docs.yml [\#67](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/67) ([CasperWA](https://github.com/CasperWA))

**Closed issues:**

- API and User Documentation [\#52](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/52)
- Test new OTEAPI calcfunctions in dummy pipeline [\#42](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/42)
- DataNode Code generation documentation and examples [\#30](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/30)
- Elaborate doc strings [\#28](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/28)
- AiiDA Workflow representing OTELib pipeline generation and execution [\#25](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/25)
- Declarative OTE pipelines [\#17](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/17)
- AiiDA data nodes for \*Config [\#16](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/16)
- Publish SDK to PYPI [\#14](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/14)
- AiiDA Calculation functions representing OTELib strategies [\#10](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/10)
- Standardise AiiDA configuration+hash IRI [\#8](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/8)
- Workflow generator  [\#4](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/4)
- Provenance integration [\#3](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/3)
- AiiDA plugin for OTEAPI [\#2](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/2)
- DataModel generation [\#1](https://github.com/H2020-OpenModel/WP3-WrapperSDK/issues/1)

**Merged pull requests:**

- \[Auto-generated\] Update dependencies [\#66](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/66) ([TEAM4-0](https://github.com/TEAM4-0))
- Add more tests [\#64](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/64) ([CasperWA](https://github.com/CasperWA))
- API and user documentation [\#60](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/60) ([quaat](https://github.com/quaat))
- Update `pre-commit` hooks \(\#53\) [\#56](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/56) ([quaat](https://github.com/quaat))
- OTE pipeline WorkChain [\#55](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/55) ([CasperWA](https://github.com/CasperWA))
- \[Auto-generated\] Update dependencies [\#53](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/53) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#50](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/50) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#48](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/48) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#46](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/46) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#45](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/45) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#43](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/43) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#40](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/40) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#38](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/38) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#34](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/34) ([TEAM4-0](https://github.com/TEAM4-0))
- \[Auto-generated\] Update dependencies [\#32](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/32) ([TEAM4-0](https://github.com/TEAM4-0))
- Added jinja2 template and example documentation [\#26](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/26) ([quaat](https://github.com/quaat))
- Dev tools \(pre-commit\), CI/CD workflows, documentation, flit [\#24](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/24) ([CasperWA](https://github.com/CasperWA))
- AiiDA calculations for OTE\(lib\) strategies [\#23](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/23) ([CasperWA](https://github.com/CasperWA))
- AiiDA Data Node classes for OTEAPI strategy configurations [\#20](https://github.com/H2020-OpenModel/WP3-WrapperSDK/pull/20) ([ajeklund](https://github.com/ajeklund))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
